## 简介

一般在 4 个地方更新：

* [https://gitee.com/mulab/oi_tools](https://gitee.com/mulab/oi_tools)：主要的工作地址，所有分支都会在这里；可以提 issue。
* [https://github.com/Mulab11/tuack](https://github.com/Mulab11/tuack)：可以提 issue，可能不会及时更新。
* <del>[https://saac.cs.tsinghua.edu.cn/publish/tuack](https://git.thusaac.org/publish/tuack)：清华校内的服务器现在搬到这里了。</del>
* <del>[https://git.thusaac.com/publish/tuack](https://git.thusaac.com/publish/tuack)：最近算协服务器又没人管了，正常所有分支都会在这里；非清华贵系算协成员不能提 issue。</del>


此外如果有任何疑问或建议，知道我 QQ 或微信的小伙伴也可以用这些工具告诉我。

这个轮子打算逐步实现：

* 合作：通过共同使用git和遵循一些约定，降低合作命题者之间版本控制，题面修改，代码、数据交换，bug修复等的成本。
* 规范：对题目的各个方面进行评估，找出可能出错的风险点，帮助出题人减少出锅的概率。
* 适配：尽量支持从现有的各类评测工具导入数据和导出到各类评测工具中，实现多种格式题面的书写和导出。

这个轮子主要是面向出题人、OJ站长和教师，方便大家造题和分享题目。

目前这个轮子还在you开yi发dui中bug。如果希望我们支持其他格式的题面，其他工具的导入导出，对这个轮子有任何建议或意见，发现了任何bug，或是有兴趣加入我们，欢迎随时联系。

## 文档

[文档在这里](https://gitee.com/mulab/oi_tools/wikis/home)
